%define upstream_name    Games-Dice
%define upstream_version 0.046

%{?perl_default_filter}

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 2

Summary:    Simulates rolling dice
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/Games/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(Exporter)
BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(File::Spec)
BuildRequires: perl(Test::MockRandom)
BuildRequires: perl(Test::More) >= 0.960.0
BuildRequires: perl(if)
BuildRequires: perl(strict)
BuildRequires: perl(warnings)
BuildArch:  noarch

%description
Games::Dice simulates die rolls. It uses a function-oriented (not
object-oriented) interface. No functions are exported by default. At
present, there are two functions which are exportable: 'roll' and
'roll_array'. The latter is used internally by 'roll', but can also be
exported by itself.

The number and type of dice to roll is given in a style which should be
familiar to players of popular role-playing games: _a_d_b_[+-*/b]_c_. _a_
is optional and defaults to 1; it gives the number of dice to roll. _b_
indicates the number of sides to each die; the most common, cube-shaped die
is thus a d6. % can be used instead of 100 for _b_; hence, rolling 2d% and
2d100 is equivalent. 'roll' simulates _a_ rolls of _b_-sided dice and adds
together the results. The optional end, consisting of one of +-*/b and a
number _c_, can modify the sum of the individual dice. +-*/ are similar in
that they take the sum of the rolls and add or subtract _c_, or multiply or
divide the sum by _c_. (x can also be used instead of *.) Hence, 1d6+2
gives a number in the range 3..8, and 2d4*10 gives a number in the range
20..80. (Using / truncates the result to an int after dividing.) Using b in
this slot is a little different: it's short for "best" and indicates "roll
a number of dice, but add together only the best few". For example, 5d6b3
rolls five six- sided dice and adds together the three best rolls. This is
sometimes used, for example, in roll-playing to give higher averages.

Generally, 'roll' probably provides the nicer interface, since it does the
adding up itself. However, in some situations one may wish to process the
individual rolls (for example, I am told that in the game Feng Shui, the
number of dice to be rolled cannot be determined in advance but depends on
whether any 6's were rolled); in such a case, one can use 'roll_array' to
return an array of values, which can then be examined or processed in an
application-dependent manner.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%__perl Makefile.PL INSTALLDIRS=vendor

%make_build

%check
%make_build test

%install
%make_install

%files
%doc Changes LICENSE META.json META.yml MYMETA.yml README
%{_bindir}/roll
%{_mandir}/man1/*
%{_mandir}/man3/*
%{perl_vendorlib}/*

%changelog
* Sat Jun 28 2025 umeabot <umeabot> 0.46.0-2.mga10
+ Revision: 2216651
- Mageia 10 Mass Rebuild

* Mon Dec 05 2022 tv <tv> 0.46.0-1.mga9
+ Revision: 1918111
- update to 0.046

* Sun Mar 20 2022 umeabot <umeabot> 0.45.0-6.mga9
+ Revision: 1803785
- Mageia 9 Mass Rebuild

* Wed Feb 12 2020 umeabot <umeabot> 0.45.0-5.mga8
+ Revision: 1494623
- Mageia 8 Mass Rebuild

* Wed Sep 19 2018 umeabot <umeabot> 0.45.0-4.mga7
+ Revision: 1268189
- Mageia 7 Mass Rebuild

* Sun Jun 19 2016 pterjan <pterjan> 0.45.0-3.mga6
+ Revision: 1027651
- Rebuild for perl 5.22.2

* Fri Feb 19 2016 umeabot <umeabot> 0.45.0-2.mga6
+ Revision: 967730
- Mageia 6 Mass Rebuild

* Sat Jul 04 2015 sander85 <sander85> 0.45.0-1.mga6
+ Revision: 850165
- update to 0.045

* Sun Oct 19 2014 umeabot <umeabot> 0.43.0-5.mga5
+ Revision: 790159
- Rebuild to potentially add missing dependencies

* Wed Oct 15 2014 umeabot <umeabot> 0.43.0-4.mga5
+ Revision: 747734
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.43.0-3.mga5
+ Revision: 684830
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 0.43.0-2.mga4
+ Revision: 533984
- Mageia 4 Mass Rebuild

* Sun Sep 08 2013 sander85 <sander85> 0.43.0-1.mga4
+ Revision: 475960
- update to 0.043

* Thu Aug 29 2013 sander85 <sander85> 0.42.0-1.mga4
+ Revision: 473010
- update to 0.042

* Mon Jun 03 2013 jquelin <jquelin> 0.40.0-1.mga4
+ Revision: 436624
- update to 0.04

* Sun Jan 13 2013 umeabot <umeabot> 0.30.0-2.mga3
+ Revision: 367623
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 08 2013 jquelin <jquelin> 0.30.0-1.mga3
+ Revision: 342186
- update to 0.03

* Thu Jan 20 2011 jquelin <jquelin> 0.20.0-1.mga1
+ Revision: 26263
- mageia rebuild
- imported package perl-Games-Dice


* Sat Dec 25 2010 Shlomi Fish <shlomif@mandriva.org> 0.20.0-1mdv2011.0
+ Revision: 624921
- import perl-Games-Dice

